@@ -4,6 +4,8 @@
 #define strcasecmp _stricmp
 #endif
 
+#include "start_response.h"
+
 typedef struct {
     int error;
     int keep_alive;
@@ -17,13 +19,6 @@ typedef struct {
     RequestState state;
 } Request;
 
-typedef struct {
-    PyObject ob_base;
-    PyObject* status;
-    PyObject* headers;
-    PyObject* exc_info;
-} StartResponse;
-
 PyObject* base_dict;
 void init_request_dict();
 void build_wsgi_environ(llhttp_t* parser);
